@@ -28,9 +28,9 @@ extensions = [
 ]
 
 # openstackdocstheme options
-repository_name = 'openstack/oslo.cache'
-bug_project = 'oslo.cache'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/oslo.cache'
+openstackdocs_bug_project = 'oslo.cache'
+openstackdocs_bug_tag = ''
 
 # sphinxcontrib.apidoc options
 apidoc_module_dir = '../../oslo_cache'
@@ -39,9 +39,6 @@ apidoc_excluded_paths = [
     'tests'
 ]
 
-# Must set this variable to include year, month, day, hours, and minutes.
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
-
 # The suffix of source filenames.
 source_suffix = '.rst'
 
@@ -49,8 +46,8 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'oslo.cache'
-copyright = u'2014, OpenStack Foundation'
+project = 'oslo.cache'
+copyright = '2014, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -60,7 +57,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # A list of ignored prefixes for module index sorting.
 modindex_common_prefix = ['oslo_cache.']
@@ -82,8 +79,8 @@ htmlhelp_basename = '%sdoc' % project
 latex_documents = [
     ('index',
      '%s.tex' % project,
-     u'%s Documentation' % project,
-     u'OpenStack Foundation', 'manual'),
+     '%s Documentation' % project,
+     'OpenStack Foundation', 'manual'),
 ]
 
 intersphinx_mapping = {
