@@ -19,6 +19,7 @@ import functools
 
 from dogpile.cache.backends import memcached as memcached_backend
 
+from oslo_cache import _bmemcache_pool
 from oslo_cache import _memcache_pool
 
 
@@ -36,21 +37,43 @@ class ClientProxy(object):
 
 
 class PooledMemcachedBackend(memcached_backend.MemcachedBackend):
-    """Memcached backend that does connection pooling."""
+    """Memcached backend that does connection pooling.
+
+    This memcached backend only allows for reuse of a client object,
+    prevents too many client object from being instantiated, and maintains
+    proper tracking of dead servers so as to limit delays when a server
+    (or all servers) become unavailable.
+
+    This backend doesn't allow to load balance things between servers.
+
+    Memcached isn't HA. Values aren't automatically replicated between servers
+    unless the client went out and wrote the value multiple time.
+
+    The memcache server to use is determined by `python-memcached` itself by
+    picking the host to use (from the given server list) based on a key hash.
+    """
 
     # Composed from GenericMemcachedBackend's and MemcacheArgs's __init__
     def __init__(self, arguments):
         super(PooledMemcachedBackend, self).__init__(arguments)
-        self.client_pool = _memcache_pool.MemcacheClientPool(
-            self.url,
-            arguments={
-                'dead_retry': arguments.get('dead_retry', 5 * 60),
-                'socket_timeout': arguments.get('socket_timeout', 3.0),
-            },
-            maxsize=arguments.get('pool_maxsize', 10),
-            unused_timeout=arguments.get('pool_unused_timeout', 60),
-            conn_get_timeout=arguments.get('pool_connection_get_timeout', 10),
-        )
+        if arguments.get('sasl_enabled', False):
+            self.client_pool = _bmemcache_pool.BMemcacheClientPool(
+                self.url,
+                arguments,
+                maxsize=arguments.get('pool_maxsize', 10),
+                unused_timeout=arguments.get('pool_unused_timeout', 60),
+                conn_get_timeout=arguments.get('pool_connection_get_timeout',
+                                               10),
+            )
+        else:
+            self.client_pool = _memcache_pool.MemcacheClientPool(
+                self.url,
+                arguments,
+                maxsize=arguments.get('pool_maxsize', 10),
+                unused_timeout=arguments.get('pool_unused_timeout', 60),
+                conn_get_timeout=arguments.get('pool_connection_get_timeout',
+                                               10),
+            )
 
     # Since all methods in backend just call one of methods of client, this
     # lets us avoid need to hack it too much
