@@ -139,10 +139,32 @@ def _build_cache_config(conf):
     # NOTE(yorik-sar): these arguments will be used for memcache-related
     # backends. Use setdefault for url to support old-style setting through
     # backend_argument=url:127.0.0.1:11211
+    #
+    # NOTE(morgan): If requested by config, 'flush_on_reconnect' will be set
+    # for pooled connections. This can ensure that stale data is never
+    # consumed from a server that pops in/out due to a network partition
+    # or disconnect.
+    #
+    # See the help from python-memcached:
+    #
+    # param flush_on_reconnect: optional flag which prevents a
+    #        scenario that can cause stale data to be read: If there's more
+    #        than one memcached server and the connection to one is
+    #        interrupted, keys that mapped to that server will get
+    #        reassigned to another. If the first server comes back, those
+    #        keys will map to it again. If it still has its data, get()s
+    #        can read stale data that was overwritten on another
+    #        server. This flag is off by default for backwards
+    #        compatibility.
+    #
+    # The normal non-pooled clients connect explicitly on each use and
+    # does not need the explicit flush_on_reconnect
     conf_dict.setdefault('%s.arguments.url' % prefix,
                          conf.cache.memcache_servers)
     for arg in ('dead_retry', 'socket_timeout', 'pool_maxsize',
-                'pool_unused_timeout', 'pool_connection_get_timeout'):
+                'pool_unused_timeout', 'pool_connection_get_timeout',
+                'pool_flush_on_reconnect', 'sasl_enabled', 'username',
+                'password'):
         value = getattr(conf.cache, 'memcache_' + arg)
         conf_dict['%s.arguments.%s' % (prefix, arg)] = value
 
@@ -167,6 +189,54 @@ def _build_cache_config(conf):
 
         conf_dict['%s.arguments.tls_context' % prefix] = tls_context
 
+    # NOTE(hberaud): Pymemcache support socket keepalive, If it is enable in
+    # our config then configure it to enable this feature.
+    # The socket keepalive feature means that pymemcache will be able to check
+    # your connected socket and determine whether the connection is still up
+    # and running or if it has broken.
+    # This could be used by users who want to handle fine grained failures.
+    if conf.cache.enable_socket_keepalive:
+        if conf.cache.backend != 'dogpile.cache.pymemcache':
+            msg = _(
+                "Socket keepalive is only supported by the "
+                "'dogpile.cache.pymemcache' backend."
+            )
+            raise exception.ConfigurationError(msg)
+        import pymemcache
+        socket_keepalive = pymemcache.KeepaliveOpts(
+            idle=conf.cache.socket_keepalive_idle,
+            intvl=conf.cache.socket_keepalive_interval,
+            cnt=conf.cache.socket_keepalive_count)
+        # As with the TLS context above, the config dict below will be
+        # consumed by dogpile.cache that will be used as a proxy between
+        # oslo.cache and pymemcache.
+        conf_dict['%s.arguments.socket_keepalive' % prefix] = socket_keepalive
+
+    # NOTE(hberaud): The pymemcache library comes with retry mechanisms that
+    # can be used to wrap all kind of pymemcache clients. The retry wrapper
+    # allow you to define how many attempts to make and how long to wait
+    # between attempts. The section below will pass our config
+    # to dogpile.cache to setup the pymemcache retry client wrapper.
+    if conf.cache.enable_retry_client:
+        if conf.cache.backend != 'dogpile.cache.pymemcache':
+            msg = _(
+                "Retry client is only supported by the "
+                "'dogpile.cache.pymemcache' backend."
+            )
+            raise exception.ConfigurationError(msg)
+        import pymemcache
+        conf_dict['%s.arguments.enable_retry_client' % prefix] = True
+        conf_dict['%s.arguments.retry_attempts' % prefix] = \
+            conf.cache.retry_attempts
+        conf_dict['%s.arguments.retry_delay' % prefix] = \
+            conf.cache.retry_delay
+        conf_dict['%s.arguments.hashclient_retry_attempts' % prefix] = \
+            conf.cache.hashclient_retry_attempts
+        conf_dict['%s.arguments.hashclient_retry_delay' % prefix] = \
+            conf.cache.hashclient_retry_delay
+        conf_dict['%s.arguments.dead_timeout' % prefix] = \
+            conf.cache.dead_timeout
+
     return conf_dict
 
 
